"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/** converts key tree to a full tree
 * @example
 * input: {
 *    'hello': {
 *      'hello/world': undefined
 *    }
 * }
 * output: {
 *  id: 'hello',
 *  children: [
 *    {
 *      id: 'hello/world',
 *      children: undefined,
 *    }
 *  ]
 * }
 */
function keyTreeToNodeTree(nodeId, children) {
    // leaf:
    if (!children) {
        return {
            id: nodeId,
            children: undefined,
        };
    }
    // innerNode:
    return {
        id: nodeId,
        children: Object.entries(children)
            .sort(alphabetically)
            .sort(foldersFirst)
            .map(([fullpath, subChildren]) => keyTreeToNodeTree(fullpath, subChildren)),
    };
}
exports.keyTreeToNodeTree = keyTreeToNodeTree;
function alphabetically([key1 /* node1 */], [key2 /* node2 */]) {
    return key1 < key2 ? -1 : 1;
}
function foldersFirst([, /* key1 */ children1], [, /* key2 */ children2]) {
    return (children1 !== undefined ? -1 : 0) + (children2 !== undefined ? 1 : 0);
}
//# sourceMappingURL=key-tree-to-node-tree.js.map