"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const key_tree_1 = require("./key-tree");
it('should return an empty node for 0 paths', () => {
    const res = key_tree_1.buildKeyTree([]);
    chai_1.expect(res).to.be.empty;
});
it('should return a leaf node for a single filepath', () => {
    const res = key_tree_1.buildKeyTree(['item']);
    chai_1.expect(res).to.deep.equal({ item: undefined });
});
it('should return a inner node for a filepath with folders', () => {
    const res = key_tree_1.buildKeyTree(['container/item']);
    chai_1.expect(res).to.deep.equal({
        'container/': {
            'container/item': undefined,
        },
    });
});
it('should make common ancestor when two nodes have the same sub path', () => {
    const res = key_tree_1.buildKeyTree(['container/sub/a', 'container/sub/b']);
    chai_1.expect(res).to.deep.equal({
        'container/': {
            'container/sub/': {
                'container/sub/a': undefined,
                'container/sub/b': undefined,
            },
        },
    });
});
it('should make a node for empty folders', () => {
    const res = key_tree_1.buildKeyTree(['container/sub/']);
    chai_1.expect(res).to.deep.equal({
        'container/': {
            'container/sub/': {},
        },
    });
});
it('should make two nodes, when receiving a folder and a file of the same name', () => {
    const res = key_tree_1.buildKeyTree(['container/', 'container']);
    chai_1.expect(res).to.deep.equal({
        'container/': {},
        container: undefined,
    });
});
//# sourceMappingURL=key-tree.specx.js.map